Saga<AR, A> class final

Reacts to action results by emitting follow-up actions.

A saga is stateless. It maps action results, often events, into next actions, often commands.

Implemented types
Available extensions

Constructors

Saga({required React<AR, A> react})
Creates a Saga.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
react React<AR, A>
Function that emits follow-up actions for an action result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

combine<AR2, A2, ARSuper, ASuper>(Saga<AR2?, A2> other) Saga<ARSuper, ASuper>

Available on Saga<AR?, A>, provided by the SagaCombineExt extension

Combines two sagas into one saga.
mapLeftOnActionResult<ARn>(AR f(ARn)) Saga<ARn, A>

Available on Saga<AR, A>, provided by the SagaMapExt extension

Adapts this saga to accept another action-result type.
mapOnAction<An>(An f(A)) Saga<AR, An>

Available on Saga<AR, A>, provided by the SagaMapExt extension

Adapts this saga to emit another action type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited