fetchState abstract method
Returns the state associated with command and its current version.
Implementation
Future<(S?, V?)> fetchState(C command);
Returns the state associated with command and its current version.
Future<(S?, V?)> fetchState(C command);