ViewStateLockingDeduplicationRepositoryDefaults<E, S, EV, SV> mixin

Default metadata behavior for ViewStateLockingDeduplicationRepository.

Implemented types

Properties

emptyMetadata NoMetadata
Empty metadata returned by default metadata methods.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchState(E event) Future<(S?, SV?)>
Returns the current state affected by event and its state version.
inherited
fetchStateWithMetadata(E event) Future<(S?, SV?, NoMetadata)>
Returns fetchState with empty metadata.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(S state, EV eventVersion, SV? currentStateVersion) Future<(S, SV)>
Persists state if the state and event versions are acceptable.
inherited
saveWithMetadata(S state, EV eventVersion, SV? currentStateVersion, NoMetadata metadata) Future<(S, SV, NoMetadata)>
Saves state and returns empty metadata.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited