Contract for computing events from commands and evolving state from events.
- Implementers
Properties
-
decide
→ Decide<
C, S, E> -
Computes new events for
commandin the current state.no setter -
evolve
→ Evolve<
S, E> -
Applies an event to a state and returns the next state.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialState → S
-
State used when no prior state exists.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited