Saga<AR, A> class
final
Reacts to action results by emitting follow-up actions.
A saga is stateless. It maps action results, often events, into next actions, often commands.
- Implemented types
-
- SagaContract<
AR, A>
- SagaContract<
- Available extensions
Properties
Methods
-
combine<
AR2, A2, ARSuper, ASuper> (Saga< AR2?, A2> other) → Saga<ARSuper, ASuper> -
Available on Saga<
Combines two sagas into one saga.AR?, A> , provided by the SagaCombineExt extension -
mapLeftOnActionResult<
ARn> (AR f(ARn)) → Saga< ARn, A> -
Available on Saga<
Adapts this saga to accept another action-result type.AR, A> , provided by the SagaMapExt extension -
mapOnAction<
An> (An f(A)) → Saga< AR, An> -
Available on Saga<
Adapts this saga to emit another action type.AR, A> , provided by the SagaMapExt extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited