StateOrchestratingComputation<C, S, E> mixin
Computes state and recursively handles saga-produced commands.
It uses a Decider and a Saga to handle commands based on the current state and produce a new state. The saga reacts to newly emitted events and recursively sends follow-up commands within the same transaction boundary.
C: command typeS: state typeE: event type
- Implemented types
-
- StateComputation<
C, S, E> - SagaContract<
E, C>
- StateComputation<
- Mixin applications
Properties
-
decide
→ Decide<
C, S, E> -
Computes new events for
commandin the current state.no setterinherited -
evolve
→ Evolve<
S, E> -
Applies an event to a state and returns the next state.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialState → S
-
State used when no prior state exists.
no setterinherited
-
react
→ React<
E, C> -
Emits follow-up actions for an action result.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeNewState(
S? state, C command) → Future< S> -
Computes new state for
commandfrom the currentstate.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited